@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2005, 2007-2014 Todd C. Miller <Todd.Miller@courtesan.com>
+ * Copyright (c) 2004-2005, 2007-2015 Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -82,7 +82,7 @@ struct sudo_nss sudo_nss_file = {
 int
 sudo_file_open(struct sudo_nss *nss)
 {
-    debug_decl(sudo_file_open, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_open, SUDOERS_DEBUG_NSS)
 
     if (def_ignore_local_sudoers)
 	debug_return_int(-1);
@@ -93,7 +93,7 @@ sudo_file_open(struct sudo_nss *nss)
 int
 sudo_file_close(struct sudo_nss *nss)
 {
-    debug_decl(sudo_file_close, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_close, SUDOERS_DEBUG_NSS)
 
     /* Free parser data structures and close sudoers file. */
     init_parser(NULL, false);
@@ -111,7 +111,7 @@ sudo_file_close(struct sudo_nss *nss)
 int
 sudo_file_parse(struct sudo_nss *nss)
 {
-    debug_decl(sudo_file_close, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_close, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	debug_return_int(-1);
@@ -136,7 +136,7 @@ sudo_file_parse(struct sudo_nss *nss)
 int
 sudo_file_setdefs(struct sudo_nss *nss)
 {
-    debug_decl(sudo_file_setdefs, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_setdefs, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	debug_return_int(-1);
@@ -159,7 +159,7 @@ sudo_file_lookup(struct sudo_nss *nss, int validated, int pwflag)
     struct privilege *priv;
     struct userspec *us;
     struct member *matching_user;
-    debug_decl(sudo_file_lookup, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_lookup, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	debug_return_int(validated);
@@ -201,9 +201,9 @@ sudo_file_lookup(struct sudo_nss *nss, int validated, int pwflag)
 	}
 	if (match == ALLOW || user_uid == 0) {
 	    /* User has an entry for this host. */
-	    SET(validated, VALIDATE_OK);
+	    SET(validated, VALIDATE_SUCCESS);
 	} else if (match == DENY)
-	    SET(validated, VALIDATE_NOT_OK);
+	    SET(validated, VALIDATE_FAILURE);
 	if (pwcheck == always && def_authenticate)
 	    SET(validated, FLAG_CHECK_USER);
 	else if (pwcheck == never || nopass == true)
@@ -267,8 +267,8 @@ sudo_file_lookup(struct sudo_nss *nss, int validated, int pwflag)
     }
     matched2:
     if (match == ALLOW) {
-	SET(validated, VALIDATE_OK);
-	CLR(validated, VALIDATE_NOT_OK);
+	SET(validated, VALIDATE_SUCCESS);
+	CLR(validated, VALIDATE_FAILURE);
 	if (tags != NULL) {
 	    if (tags->nopasswd != UNSPEC)
 		def_authenticate = !tags->nopasswd;
@@ -282,8 +282,8 @@ sudo_file_lookup(struct sudo_nss *nss, int validated, int pwflag)
 		def_log_output = tags->log_output;
 	}
     } else if (match == DENY) {
-	SET(validated, VALIDATE_NOT_OK);
-	CLR(validated, VALIDATE_OK);
+	SET(validated, VALIDATE_FAILURE);
+	CLR(validated, VALIDATE_SUCCESS);
 	if (tags != NULL && tags->nopasswd != UNSPEC)
 	    def_authenticate = !tags->nopasswd;
     }
@@ -301,7 +301,7 @@ static void
 sudo_file_append_cmnd(struct cmndspec *cs, struct cmndtag *tags,
     struct sudo_lbuf *lbuf)
 {
-    debug_decl(sudo_file_append_cmnd, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_append_cmnd, SUDOERS_DEBUG_NSS)
 
 #ifdef HAVE_PRIV_SET
     if (cs->privs)
@@ -340,8 +340,7 @@ sudo_file_append_cmnd(struct cmndspec *cs, struct cmndtag *tags,
 }
 
 #define	RUNAS_CHANGED(cs1, cs2) \
-	(cs1 == NULL || cs2 == NULL || \
-	 cs1->runasuserlist != cs2->runasuserlist || \
+	(cs1->runasuserlist != cs2->runasuserlist || \
 	 cs1->runasgrouplist != cs2->runasgrouplist)
 
 static int
@@ -353,7 +352,7 @@ sudo_file_display_priv_short(struct passwd *pw, struct userspec *us,
     struct privilege *priv;
     struct cmndtag tags;
     int nfound = 0;
-    debug_decl(sudo_file_display_priv_short, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_priv_short, SUDOERS_DEBUG_NSS)
 
     /* gcc -Wuninitialized false positive */
     tags.noexec = UNSPEC;
@@ -366,7 +365,7 @@ sudo_file_display_priv_short(struct passwd *pw, struct userspec *us,
 	    continue;
 	prev_cs = NULL;
 	TAILQ_FOREACH(cs, &priv->cmndlist, entries) {
-	    if (RUNAS_CHANGED(cs, prev_cs)) {
+	    if (prev_cs == NULL || RUNAS_CHANGED(cs, prev_cs)) {
 		if (cs != TAILQ_FIRST(&priv->cmndlist))
 		    sudo_lbuf_append(lbuf, "\n");
 		sudo_lbuf_append(lbuf, "    (");
@@ -449,7 +448,7 @@ sudo_file_display_priv_long(struct passwd *pw, struct userspec *us,
     struct member *m;
     struct privilege *priv;
     int nfound = 0, olen;
-    debug_decl(sudo_file_display_priv_long, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_priv_long, SUDOERS_DEBUG_NSS)
 
     TAILQ_FOREACH(priv, &us->privileges, entries) {
 	if (hostlist_matches(&priv->hostlist) != ALLOW)
@@ -528,7 +527,7 @@ sudo_file_display_privs(struct sudo_nss *nss, struct passwd *pw,
 {
     struct userspec *us;
     int nfound = 0;
-    debug_decl(sudo_file_display_priv, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_priv, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	goto done;
@@ -556,7 +555,7 @@ sudo_file_display_defaults(struct sudo_nss *nss, struct passwd *pw,
     struct defaults *d;
     char *prefix;
     int nfound = 0;
-    debug_decl(sudo_file_display_defaults, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_defaults, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	goto done;
@@ -607,7 +606,7 @@ sudo_file_display_bound_defaults(struct sudo_nss *nss, struct passwd *pw,
     struct sudo_lbuf *lbuf)
 {
     int nfound = 0;
-    debug_decl(sudo_file_display_bound_defaults, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_bound_defaults, SUDOERS_DEBUG_NSS)
 
     /* XXX - should only print ones that match what the user can do. */
     nfound += display_bound_defaults(DEFAULTS_RUNAS, lbuf);
@@ -627,7 +626,7 @@ display_bound_defaults(int dtype, struct sudo_lbuf *lbuf)
     struct member *m;
     char *dsep;
     int atype, nfound = 0;
-    debug_decl(display_bound_defaults, SUDO_DEBUG_NSS)
+    debug_decl(display_bound_defaults, SUDOERS_DEBUG_NSS)
 
     switch (dtype) {
 	case DEFAULTS_HOST:
@@ -686,7 +685,7 @@ sudo_file_display_cmnd(struct sudo_nss *nss, struct passwd *pw)
     struct userspec *us;
     int rval = 1;
     int host_match, runas_match, cmnd_match;
-    debug_decl(sudo_file_display_cmnd, SUDO_DEBUG_NSS)
+    debug_decl(sudo_file_display_cmnd, SUDOERS_DEBUG_NSS)
 
     if (nss->handle == NULL)
 	goto done;
@@ -734,7 +733,7 @@ _print_member(struct sudo_lbuf *lbuf, char *name, int type, int negated,
     struct alias *a;
     struct member *m;
     struct sudo_command *c;
-    debug_decl(_print_member, SUDO_DEBUG_NSS)
+    debug_decl(_print_member, SUDOERS_DEBUG_NSS)
 
     switch (type) {
 	case ALL:
