@@ -143,14 +143,14 @@ next_entry:
     if ((colon = strchr(cp = colon, ':')) == NULL)
 	goto next_entry;
     *colon++ = '\0';
-    id = atoid(cp, NULL, NULL, &errstr);
+    id = sudo_strtoid(cp, NULL, NULL, &errstr);
     if (errstr != NULL)
 	goto next_entry;
     pw.pw_uid = (uid_t)id;
     if ((colon = strchr(cp = colon, ':')) == NULL)
 	goto next_entry;
     *colon++ = '\0';
-    id = atoid(cp, NULL, NULL, &errstr);
+    id = sudo_strtoid(cp, NULL, NULL, &errstr);
     if (errstr != NULL)
 	goto next_entry;
     pw.pw_gid = (gid_t)id;
@@ -273,7 +273,7 @@ next_entry:
     if ((colon = strchr(cp = colon, ':')) == NULL)
 	goto next_entry;
     *colon++ = '\0';
-    id = atoid(cp, NULL, NULL, &errstr);
+    id = sudo_strtoid(cp, NULL, NULL, &errstr);
     if (errstr != NULL)
 	goto next_entry;
     gr.gr_gid = (gid_t)id;
