@@ -52,7 +52,7 @@
 #include <grp.h>
 #include <pwd.h>
 
-#include "missing.h"
+#include "sudo_compat.h"
 #include "sudo_dso.h"
 #include "sudo_plugin.h"
 #include "sudo_util.h"
@@ -135,7 +135,7 @@ sysgroup_query(const char *user, const char *group, const struct passwd *pwd)
     grp = sysgroup_getgrnam(group);
     if (grp == NULL && group[0] == '#' && group[1] != '\0') {
 	const char *errstr;
-	gid_t gid = atoid(group + 1, NULL, NULL, &errstr);
+	gid_t gid = sudo_strtoid(group + 1, NULL, NULL, &errstr);
 	if (errstr == NULL)
 	    grp = sysgroup_getgrgid(gid);
     }
