@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2014 Todd C. Miller <Todd.Miller@courtesan.com>
+ * Copyright (c) 2013-2015 Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -99,13 +99,11 @@ add_preserved_fd(struct preserved_fd_list *pfds, int fd)
 void
 closefrom_except(int startfd, struct preserved_fd_list *pfds)
 {
-    int debug_fd, fd, lastfd = -1;
+    int fd, lastfd = -1;
     struct preserved_fd *pfd, *pfd_next;
     fd_set *fdsp;
     debug_decl(closefrom_except, SUDO_DEBUG_UTIL)
 
-    debug_fd = sudo_debug_fd_get();
-
     /* First, relocate preserved fds to be as contiguous as possible.  */
     TAILQ_FOREACH_REVERSE_SAFE(pfd, pfds, preserved_fd_list, entries, pfd_next) {
 	if (pfd->highfd < startfd)
@@ -120,12 +118,11 @@ closefrom_except(int startfd, struct preserved_fd_list *pfds)
 	    }
 	    /* NOTE: still need to adjust lastfd below with unchanged lowfd. */
 	} else if (fd < pfd->highfd) {
-	    pfd->lowfd = fd;
-	    fd = pfd->highfd;
-	    if (fd == debug_fd)
-		debug_fd = sudo_debug_fd_set(pfd->lowfd);
 	    sudo_debug_printf(SUDO_DEBUG_DEBUG|SUDO_DEBUG_LINENO,
 		"dup %d -> %d", pfd->highfd, pfd->lowfd);
+	    sudo_debug_update_fd(pfd->highfd, pfd->lowfd);
+	    pfd->lowfd = fd;
+	    fd = pfd->highfd;
 	}
 	if (fd != -1)
 	    (void) close(fd);
@@ -191,8 +188,7 @@ closefrom_except(int startfd, struct preserved_fd_list *pfds)
 		sudo_debug_printf(SUDO_DEBUG_DEBUG|SUDO_DEBUG_LINENO,
 		    "fcntl(%d, F_SETFD, %d)", pfd->highfd, pfd->flags);
 	    }
-	    if (pfd->lowfd == debug_fd)
-		debug_fd = sudo_debug_fd_set(pfd->highfd);
+	    sudo_debug_update_fd(pfd->lowfd, pfd->highfd);
 	    (void) close(pfd->lowfd);
 	    pfd->lowfd = pfd->highfd;
 	}
